PCB Environment: Point_25 Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions
Point_25 Class Reference

`#include <Geometry.hpp>`

## Public Member Functions
| Point_25 (const Point_2 &x, int z)
| Point_25 (Real x, Real y, int z)
const Point_2 & | xy () const
Real | x () const
Real | y () const
int | z () const
Point_25 | withZ (int z) const
Bbox_2 | bbox () const
Point_25 & | operator= (const Point_25 &v)
bool | operator< (const Point_25 &v) const
bool | operator== (const Point_25 &v) const
Point_25 | operator+ (const Vector_2 &v) const

## Detailed Description

2.5D (2 continuous + 1 discrete) Point class.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Geometry.hpp